﻿/*

///////////////////////////////////////
// JavaScript for InDesign CS2
// 表組基本設定(履歴付き)1.0.2
// 2006.10.24版
///////////////////////////////////////

Copyright [2006.10.24] [いき♂] 
	変更点：表の内側の線を縦横別々に指定できるようにした

Copyright [2006.08.09] [いき♂] 
	変更点：表の上下と左右の線を別々に指定できるようにした

Copyright [2006.08.07] [こむぎ]

Apache License Version 2.0（「本ライセンス」）に基づいてライセンスされます。
あなたがこのファイルを使用するためには、本ライセンスに従わなければなりません。
本ライセンスのコピーは下記の場所から入手できます。
http://www.apache.org/licenses/LICENSE-2.0

*動作確認環境

Mac OS X版InDesign CS/CS2
Windows版InDesign CS/CS2

*インストール

Mac版
/Applications/Adobe InDesign CS2_J/Presets/Scripts/ にtable_initialize102.jsをコピー。

Windows版
C:\Program Files\Adobe\Adobe InDesign CS\Presets\Scripts にtable_initialize102.jsをコピー

バージョン違いについては、適宜読み替えてください。

*実行方法

「ウィンドウ＞自動化＞スクリプト」から実行するか、
「編集＞キーボードショートカット...」の「機能エリア＞スクリプト」で
キーボードショートカットを割り当てる

*使い方

表組かセルかセルの中身を選んだ状態で起動。
セルの線の線幅と、表の上端・下端の線幅、表の右端・左端の線幅、セルの余白を指定できます。
一度入力した数値は、次回起動時にも覚えています。

項目間はTabかShift+Tabで移動可能です。
EnterキーでOKボタンを押せます。

履歴は、スクリプト設置ディレクトリに「table_initialize102_history.txt」という名前で保存されます。

*連絡

こむぎ
http://mixi.jp/show_friend.pl?id=41200

いき♂@∞
http://mixi.jp/show_friend.pl?id=1284900
*/

// セルの横線の線幅デフォルト値
defaultHorizontalStroke = 0.125;
// セルの縦線の線幅デフォルト値
defaultVerticalStroke = 0.125;
// 表の上端及び下端の線幅デフォルト値
defaultJougeStroke = 0.25;
// 表の右端及び左端の線幅デフォルト値
defaultSayuuStroke = 0;
// セルの余白デフォルト値
defaultInset = 0.25;

// 入力履歴保存ファイルファイル名
var HISTORY_FILE_NAME = "table_initialize102_history.txt"

// ラベルの横幅
var myLabelWidth = 180;

// コントロールの横幅
var myControlWidth = 60;

// 自身の親ディレクトリを戻すfunction
// InDesign（のスクリプトパレット）から実行しないと動作せず
function scriptPath()
{
	tempArray = new Array();
	tempArray = app.activeScript.toString().split("/");
	return tempArray.slice(0, tempArray.length - 1).join("/") + "/";
}

// 主処理
// 客観的に見て非常に汚いソースなので、ちゃんとした書き方については
// Adobeの由緒正しいサンプルを見てください

if(app.documents.length != 0)
{
	if(app.selection.length > 0)
	{
		mySel = false;
		constructorName = app.selection[0].constructor.name;

		// 表が選ばれていたら（セルが全選択中だったら）
		if(constructorName == "Table")
		{
			mySel = app.selection[0];
		}
		// セルが選ばれていたら
		else if (constructorName == "Cell" && app.selection[0].parent.constructor.name == "Table")
		{
			mySel = app.selection[0].parent;
		}
		// 表の中身が選ばれていたら
		else if (constructorName.match(/InsertionPoint|Character|Text|Paragraph/) &&
			app.selection[0].parent.parent.constructor.name == "Table")
		{
			mySel = app.selection[0].parent.parent;
		}
		else
		{
			noSelErr();
		}

		if(mySel != false)
		{
			// 履歴格納用配列の用意
			histArray = new Array();

			// 履歴ファイルの存在確認
			filename = scriptPath() + HISTORY_FILE_NAME;
			fileObj = new File(filename);

			// 履歴ファイルが存在したら読み込み
			if(fileObj.exists)
			{
				// ファイル開けたら
				if(fileObj.open("r"))
				{
					// アンシリアライズし、配列に戻す
					histArray = eval(fileObj.read());

					// ファイル閉じる
					fileObj.close();
				} else {
					alert("ファイルが開けませんでした");
				}
			}
			else
			{
				// デフォルト値
				histArray = [defaultHorizontalStroke, defaultVerticalStroke, defaultJougeStroke, defaultSayuuStroke, defaultInset];
			}

			// ダイアログの土台の生成とタイトル名の付与
			var myDialog = app.dialogs.add({name:"表組基本設定"});

				// 生成したダイアログの中身を構築
				with(myDialog.dialogColumns.add())
				{
					with(dialogRows.add())
					{
						// ラベル類の列
						with(dialogColumns.add())
						{
							// 1行目
							staticTexts.add({staticLabel:"セルの横線の線幅:", minWidth:myLabelWidth});

							// 2行目
							staticTexts.add({staticLabel:"セルの縦線の線幅:", minWidth:myLabelWidth});

							// 3行目
							staticTexts.add({staticLabel:"表の上端及び下端の線幅:", minWidth:myLabelWidth});

							// 4行目
							staticTexts.add({staticLabel:"表の右端及び左端の線幅:", minWidth:myLabelWidth});

							// 5行目
							staticTexts.add({staticLabel:"セルの余白:", minWidth:myLabelWidth});
						}

						// コントロール類の列
						with(dialogColumns.add())
						{
							// 1行目
							// 表内横罫線用のエディットボックス追加
							var HorizontalStrokeField = realEditboxes.add({editValue:histArray[0], minWidth:myControlWidth});

							// 2行目
							// 表内縦罫線用のエディットボックス追加
							var VerticalStrokeField = realEditboxes.add({editValue:histArray[1], minWidth:myControlWidth});

							// 3行目
							// 表上下枠罫線用
							var jougeStrokeField = realEditboxes.add({editValue:histArray[2], minWidth:myControlWidth});

							// 4行目
							// 表左右枠罫線用
							var sayuuStrokeField = realEditboxes.add({editValue:histArray[3], minWidth:myControlWidth});

							// 5行目
							// 表内マージン用
							var insetField = realEditboxes.add({editValue:histArray[4], minWidth:myControlWidth});
						}
					}
				}

			// ダイアログの表示
			var myResult = myDialog.show();

			// OKボタンが押されていたら
			if(myResult)
			{
				// 履歴格納用配列をシリアライズ
				serializeArray = [HorizontalStrokeField.editValue, VerticalStrokeField.editValue, jougeStrokeField.editValue, sayuuStrokeField.editValue, insetField.editValue].toSource();

				// シリアライズした履歴格納用配列をテキストとして書き出し(上書き)
				filename = scriptPath() + HISTORY_FILE_NAME;

				fileObj = new File(filename);

				if (fileObj.open("w"))
				{
					fileObj.write(serializeArray);
					fileObj.close();
				} else {
					alert("ファイルが開けませんでした");
				}

				with(mySel.cells.everyItem())
				{
					topEdgeStrokeWeight = bottomEdgeStrokeWeight = jougeStrokeField.editValue;
					leftEdgeStrokeWeight = rightEdgeStrokeWeight = sayuuStrokeField.editValue;
					topInset = rightInset = leftInset = bottomInset = insetField.editValue;
					verticalJustification = VerticalJustification.centerAlign;
				}

				maxCellCount = mySel.bodyRowCount * mySel.columnCount;

				// なぜかinnerColumnStrokeWeight、innerRowStrokeWeightは
				// itemByRange()メソッド経由でないと適用できない。
				with(mySel.cells.itemByRange(0, maxCellCount - 1))
				{
					innerRowStrokeWeight = HorizontalStrokeField.editValue;
					innerColumnStrokeWeight = VerticalStrokeField.editValue;
				}
			}
		}
	}
	else
	{
		noSelErr();
	}
}
else
{
	alert("ドキュメントが開かれていません。ドキュメントを開いてから再実行してください");
}

function noSelErr()
{
	alert("TableかCellかCellの中を選んでください");
}
